@@ -13,7 +13,7 @@
 #' facets) are returned now; index to the one(s) you want. See [occ_data()]
 #' if you just want the data component
 #' @param ... additional facet parameters
-#' @seealso [downloads()], [occ_data()], [occ_facet()]
+#' @seealso [downloads()], [occ_data()]
 #' @note Maximum number of records you can get with this function is 100,000.
 #' See https://www.gbif.org/developer/occurrence
 #' @return An object of class `gbif`, which is a S3 class list, with
@@ -93,7 +93,8 @@ occ_search <- function(taxonKey=NULL,
                        relativeOrganismQuantity = NULL,
                        iucnRedListCategory = NULL,
                        lifeStage = NULL,
-                       isInCluster = NULL, 
+                       isInCluster = NULL,
+                       distanceFromCentroidInMeters=NULL,
                        limit=500,
                        start=0,
                        fields = 'all',
@@ -103,53 +104,55 @@ occ_search <- function(taxonKey=NULL,
                        facetMultiselect = NULL,
                        skip_validate = TRUE,
                        curlopts = list(), ...) {
-
+  
   pchk(return, "occ_search")
   geometry <- geometry_handler(geometry, geom_big, geom_size, geom_n)
   url <- paste0(gbif_base(), '/occurrence/search')
   argscoll <- NULL
-
+  
   .get_occ_search <- function(x=NULL, itervar=NULL, curlopts = list()) {
     if (!is.null(x)) {
       assign(itervar, x)
     }
-
+    
     # check that wkt is proper format and of 1 of 4 allowed types
     geometry <- check_wkt(geometry, skip_validate = skip_validate)
-
+    
     # check limit and start params
     check_vals(limit, "limit")
     check_vals(start, "start")
-
+    
+    # args that take a single value
     args <- rgbif_compact(
       list(
         hasCoordinate = hasCoordinate,
-        lastInterpreted = lastInterpreted,
-        decimalLatitude = decimalLatitude,
-        decimalLongitude = decimalLongitude,
         hasGeospatialIssue = hasGeospatialIssue,
         occurrenceStatus = occurrenceStatus,
         q = search,
         repatriated = repatriated,
-        elevation = elevation,
-        depth = depth, 
         limit = check_limit(as.integer(limit)),
-        eventDate = eventDate, 
-        month = month, 
-        year = year,
-        coordinateUncertaintyInMeters = coordinateUncertaintyInMeters,
-        organismQuantity = organismQuantity,
-        organismQuantityType = organismQuantityType,
-        relativeOrganismQuantity = relativeOrganismQuantity,
         isInCluster = isInCluster,
         offset = check_limit(as.integer(start))
       )
     )
+    # args that can take multiple values 
     args <- c(
       args, 
       parse_issues(issue),
       collargs("facet"),
       yank_args(...),
+      convmany(lastInterpreted),
+      convmany(decimalLatitude),
+      convmany(decimalLongitude),
+      convmany(elevation),
+      convmany(depth), 
+      convmany(eventDate), 
+      convmany(month), 
+      convmany(year),
+      convmany(coordinateUncertaintyInMeters),
+      convmany(organismQuantity),
+      convmany(organismQuantityType),
+      convmany(relativeOrganismQuantity),
       convmany(taxonKey),
       convmany(scientificName),
       convmany(country),
@@ -191,11 +194,11 @@ occ_search <- function(taxonKey=NULL,
       convmany(networkKey),
       convmany(occurrenceId),
       convmany(iucnRedListCategory),
-      convmany(lifeStage)
-      )
-
+      convmany(lifeStage),
+      convmany(distanceFromCentroidInMeters)
+    )
     argscoll <<- args
-
+    
     if (limit >= 300) {
       ### loop route for no facet and limit>0
       iter <- 0
@@ -204,17 +207,17 @@ occ_search <- function(taxonKey=NULL,
       while (sumreturned < limit) {
         iter <- iter + 1
         tt <- gbif_GET(url, args, FALSE, curlopts)
-
+        
         # if no results, assign count var with 0
         if (identical(tt$results, list())) tt$count <- 0
-
+        
         numreturned <- length(tt$results)
         sumreturned <- sumreturned + numreturned
-
+        
         if (tt$count < limit) {
           limit <- tt$count
         }
-
+        
         if (sumreturned < limit) {
           args$limit <- limit - sumreturned
           args$offset <- sumreturned + start
@@ -225,7 +228,7 @@ occ_search <- function(taxonKey=NULL,
       ### loop route for facet or limit=0
       outout <- list(gbif_GET(url, args, FALSE, curlopts))
     }
-
+    
     meta <- outout[[length(outout)]][c('offset', 'limit', 'endOfRecords',
                                        'count')]
     data <- do.call(c, lapply(outout, "[[", "results"))
@@ -249,7 +252,7 @@ occ_search <- function(taxonKey=NULL,
     list(meta = meta, hierarchy = hier2, data = dat2,
          media = media, facets = fac)
   }
-
+  
   params <- list(
     taxonKey=taxonKey,
     scientificName=scientificName,
@@ -304,8 +307,9 @@ occ_search <- function(taxonKey=NULL,
     relativeOrganismQuantity=relativeOrganismQuantity,
     iucnRedListCategory=iucnRedListCategory,
     lifeStage=lifeStage,
-    coordinateUncertaintyInMeters = coordinateUncertaintyInMeters
-    )
+    coordinateUncertaintyInMeters=coordinateUncertaintyInMeters,
+    distanceFromCentroidInMeters=distanceFromCentroidInMeters
+  )
   if (!any(sapply(params, length) > 0)) {
     stop(sprintf("At least one of these parameters must have a value:\n%s",
                  possparams()),
@@ -317,7 +321,7 @@ occ_search <- function(taxonKey=NULL,
                  possparams()),
          call. = FALSE)
   }
-
+  
   if (length(iter) == 0) {
     out <- .get_occ_search(curlopts = curlopts)
   } else {
@@ -325,13 +329,13 @@ occ_search <- function(taxonKey=NULL,
                   curlopts = curlopts)
     names(out) <- transform_names(iter[[1]])
   }
-
+  
   if (any(names(argscoll) %in% names(iter))) {
     argscoll[[names(iter)]] <- iter[[names(iter)]]
   }
   argscoll$fields <- fields
   structure(out, class = "gbif", args = argscoll,
-    type = if (length(iter) == 0) "single" else "many")
+            type = if (length(iter) == 0) "single" else "many")
 }
 
 # helpers -------------------------
@@ -349,5 +353,6 @@ possparams <- function(){
   recordNumber, search, institutionCode, collectionCode, decimalLatitude,
   decimalLongitude, depth, year, typeStatus, lastInterpreted, occurrenceStatus,
   continent, gadmGid, verbatimScientificName, eventId, identifiedBy, networkKey, 
-  occurrenceId, iucnRedListCategory, lifeStage, degreeOfEstablishment, or mediatype"
+  occurrenceId, iucnRedListCategory, lifeStage, degreeOfEstablishment, 
+  distanceFromCentroidInMeters, or mediatype"
 }
