@@ -36,7 +36,8 @@ test_that("occ_download_prep", {
 test_that("occ_download_prep print method", {
   skip_on_cran()
 
-  wkt <- randgeo::wkt_polygon(num_vertices = 30)
+  wkt <- "POLYGON ((1.1956196 31.6685274, 1.3014544 24.6501195, 2.5809994 25.4794093, 7.7447434 28.8910764, 7.0164007 26.8049712, 6.3937614 24.6883661, 10.6658621 23.0559085, 8.2558841 23.0358775, 5.8351769 22.5865697, 10.4505920 20.2873468, 1.5327929 23.8831332, 8.1689468 19.2218276, 1.5273958 23.7558439, 2.5291622 22.5315021, 3.6335872 21.2935462, 3.5394433 21.3562142, 4.0220814 16.8647554, 2.2146242 18.4152832, 0.3259253 14.7660454, 0.5718516 21.6252550, -0.7310904 21.5560907, -0.4340908 22.3753377, -1.1388369 21.7340427, 0.2977394 23.4751048, 0.8964301 24.1903765, 0.5309763 24.4781934, -0.6874591 25.3129101, -0.008445779 25.546685347, -1.5111521 29.2516804, 0.6816945 26.9554070, 1.1956196 31.6685274))"
+  
   z <- occ_download_prep(
     pred_in(key="basisOfRecord", value=c("HUMAN_OBSERVATION", "OBSERVATION")),
     pred("hasCoordinate", TRUE),
